/*
	*
	* Copyright 2019-2021 Britanicus <marcusbritanicus@gmail.com>
	*
	* This file is a part of DesQ project ( https://gitlab.com/desq/ )
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* at your option, any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*
*/

#pragma once

#include <QtCore>
#include <QtGui>
#include <QtDBus>

class DesQSettingsDaemon : public QObject {
	Q_OBJECT;

	public:
		/*
			* @project -> Project like DesQ or Oyster
			* @app -> Settings of a specific app: Like Files, Term, Shell, etc...
		*/
		DesQSettingsDaemon( QString project );
		bool isServiceRunning();
		bool isObjectRegistered();

	public Q_SLOTS:
		void reload();

		QVariantMap value( QString app, QString key );
		void setValue( QVariantMap value );

	private:
		QString mProject;

		/* A map of settings for each app */
		QMap<QString, QSettings *> mUserSettingsMap;
		QMap<QString, QSettings *> mDefSettingsMap;

		QMap<QString, QVariantMap> mOldSettingsData;
		QMap<QString, QString> fileAppMap;

		QFileSystemWatcher *confWatcher;

		bool serviceRunning;
		bool objectRegistered;

		void handleFileChanged( QString );

	Q_SIGNALS:
		void settingChanged( QVariantMap );
};
